@@ -1,12 +1,8 @@
-#[macro_use]
-extern crate ndarray;
-extern crate ndarray_npy;
-
-use ndarray::prelude::*;
-use ndarray_npy::{NpzReader, NpzWriter, ReadNpzError, WriteNpzError};
+use ndarray::{array, Array1, Array2};
+use ndarray_npy::{NpzReader, NpzWriter};
 use std::fs::File;
 
-fn write_example() -> Result<(), WriteNpzError> {
+fn write_example() -> Result<(), Box<dyn std::error::Error>> {
     let mut npz = NpzWriter::new(File::create("arrays.npz")?);
     let a: Array2<i32> = array![[1, 2, 3], [4, 5, 6]];
     let b: Array1<i32> = array![7, 8, 9];
@@ -15,7 +11,7 @@ fn write_example() -> Result<(), WriteNpzError> {
     Ok(())
 }
 
-fn read_example() -> Result<(), ReadNpzError> {
+fn read_example() -> Result<(), Box<dyn std::error::Error>> {
     let mut npz = NpzReader::new(File::open("arrays.npz")?)?;
     let a: Array2<i32> = npz.by_name("a")?;
     let b: Array1<i32> = npz.by_name("b")?;
